@@ -612,6 +612,7 @@ def load_daily(
         filtered_months = [m for m in available_months if start <= m <= end]
         if not filtered_months:
             raise ValueError("No parquet files found within the specified month range.")
+        selected_months = filtered_months
     else:
         _validate_contiguity(available_months)
         selected_months = available_months
@@ -709,7 +710,7 @@ def load_daily(
             for col in ["open", "high", "low", "close"]:
                 rate = row[col]
                 combined_df.loc[index, col] = (
-                    face_value / (1 + rate) ** years_to_maturity
+                    face_value / (1 + rate / 100) ** years_to_maturity
                 )
 
     combined_df = combined_df.sort_values(["date", "symbol"]).reset_index(drop=True)
@@ -727,6 +728,7 @@ def __extract_years_to_maturity(bond_symbol):
             return time_value  # It's already in years
         elif time_unit == "M":
             return time_value / 12  # Convert months to years
+    return None
 
 
 def extend_etfs(
@@ -772,12 +774,15 @@ def extend_etfs(
     for value in mapping.values():
         grouped_path_symbols[value[0]].append(value[1])
     grouped_path_symbols = dict(grouped_path_symbols)
+
+    # 关键修复：加载所有可用的月份数据，不受month_range限制
+    # 这样可以确保我们有足够的历史数据来进行ETF扩展
     df_others = pd.concat(
         [
             load_daily(
                 asset_type=asset_type,
                 symbols=symbols,
-                month_range=month_range,
+                month_range=None,  # 不限制月份范围，加载所有可用数据
                 cache=cache,
                 to_usd=True,
             )
@@ -829,6 +834,23 @@ def extend_etfs(
 
     # Concatenate all frames to form the final dataframe
     df = pd.concat(frames).sort_values(by=["date", "symbol"]).reset_index(drop=True)
+
+    if month_range:
+        start_date, end_date = month_range
+        start_date = pd.to_datetime(start_date.replace(".", "-") + "-01")
+        end_year, end_month = map(int, end_date.split("."))
+        if end_month == 12:
+            next_year = end_year + 1
+            next_month = 1
+        else:
+            next_year = end_year
+            next_month = end_month + 1
+        end_date = pd.to_datetime(f"{next_year}-{next_month:02d}-01") - pd.Timedelta(
+            days=1
+        )
+
+        df = df[(df["date"] >= start_date) & (df["date"] <= end_date)]
+
     return df
 
 
